/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, Renderer2, AfterViewInit } from '@angular/core';
import { LoaderType } from './models/type';
import { LoaderThemeColor } from './models/theme-color';
import { LoaderSize } from './models/size';
import * as i0 from "@angular/core";
/**
 * Represents the [Kendo UI Loader component for Angular]({% slug overview_loader %}).
 * Displays a Loader that represents an indeterminate wait time.
 *
 * Provides configuration options for animation type, theme color, and size.
 *
 * @example
 * ```html
 * <kendo-loader [type]="'infinite-spinner'" [themeColor]="'primary'" [size]="'large'"></kendo-loader>
 * ```
 */
export declare class LoaderComponent implements AfterViewInit {
    private element;
    private renderer;
    hostClass: boolean;
    /**
     * Specifies the Loader animation type.
     *
     * @default pulsing
     */
    set type(type: LoaderType);
    get type(): LoaderType;
    /**
     * Specifies the theme color of the Loader.
     *
     * @default primary
     */
    set themeColor(themeColor: LoaderThemeColor);
    get themeColor(): LoaderThemeColor;
    /**
     * Specifies the size of the Loader.
     *
     * @default medium
     */
    set size(size: LoaderSize);
    get size(): LoaderSize;
    private _type;
    private _themeColor;
    private _size;
    private loader;
    constructor(element: ElementRef, renderer: Renderer2);
    ngAfterViewInit(): void;
    /**
     * @hidden
     */
    get segmentCount(): Array<any>;
    private setLoaderClasses;
    static ɵfac: i0.ɵɵFactoryDeclaration<LoaderComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<LoaderComponent, "kendo-loader", never, { "type": { "alias": "type"; "required": false; }; "themeColor": { "alias": "themeColor"; "required": false; }; "size": { "alias": "size"; "required": false; }; }, {}, never, never, true, never>;
}
