/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Renderer2, ElementRef, AfterViewInit } from "@angular/core";
import { SkeletonAnimation, SkeletonShape } from "./models";
import * as i0 from "@angular/core";
/**
 * Represents the [Kendo UI Skeleton component for Angular]({% slug overview_skeleton %}).
 * Displays a Skeleton placeholder that represents loading content.
 *
 * Provides configuration options for animation, shape, width, and height.
 *
 * @example
 * ```html
 * <kendo-skeleton [shape]="'circle'" [animation]="'wave'" width="40px" height="40px"></kendo-skeleton>
 * ```
 */
export declare class SkeletonComponent implements AfterViewInit {
    private renderer;
    private hostElement;
    /**
     * Specifies the animation settings of the Skeleton.
     *
     * @default pulse
     */
    set animation(animation: SkeletonAnimation);
    get animation(): SkeletonAnimation;
    /**
     * Specifies the shape of the Skeleton.
     *
     * @default text
     */
    set shape(shape: SkeletonShape);
    get shape(): SkeletonShape;
    /**
     * Specifies the width of the Skeleton component.
     * Required for all Skeleton shapes.
     * Accepts a string like `100px`, `3em`, or `50%`, or an integer number for pixels.
     */
    set width(width: string | number);
    /**
     * Specifies the height of the Skeleton component.
     * Required for `circle` and `rectangle` shapes.
     * Not required for `text`, as it derives from the current CSS font-size.
     * Accepts a string like `100px`, `3em`, or `50%`, or an integer number for pixels.
     */
    set height(height: string | number);
    private _animation;
    private _shape;
    constructor(renderer: Renderer2, hostElement: ElementRef);
    ngAfterViewInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SkeletonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SkeletonComponent, "kendo-skeleton", never, { "animation": { "alias": "animation"; "required": false; }; "shape": { "alias": "shape"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; }, {}, never, never, true, never>;
}
